//======================================================================
//  GivParser.h - A giv parser class
//
//  Dov Grobgeld <dov.grobgeld@gmail.com>
//  Sun Nov  4 22:52:41 2007
//----------------------------------------------------------------------

#ifndef GIV_PARSER_H
#define GIV_PARSER_H

#include "giv_data.h"
#include "plis/plis.h"
#include <map>
#include <vector>

class GivParser {
 public:
    enum orientation_t {
        ORIENTATION_UNDEF,
        ORIENTATION_FLIP,
        ORIENTATION_UNFLIP
    };

    GivParser();

    typedef void (*file_reference_t)(const char *filename, gpointer data);
    typedef void (*set_orientation_t)(orientation_t horint,
                                      orientation_t vorint,
                                      gpointer data);

    void set_reference_callback(file_reference_t fr, gpointer user_data);
    void set_orientation_callback(set_orientation_t fr, gpointer user_data);
    int parse_file(const char *filename);
    void giv_style_add_string(const char* style_name,
                              const char* style_string);
    void giv_set_props_from_style(giv_dataset_t *marks,
                                  const char *style_name);
    void clear();
    GivData& get_giv_datasets() {
        return giv_datasets;
    }
    void get_data_bbox(double &min_x, double& min_y,
                       double &max_x, double& max_y);
    void set_quiver_scale(double quiver_scale);
    double get_quiver_scale() {
        return quiver_scale;
    }

 private:
    int giv_marks_data_add_line(giv_dataset_t *marks,
                                const char *line,
                                const char *filename,
                                int linenum);

    GivData giv_datasets;
    std::map<plis::slip, plis::llip > style_hash;
    file_reference_t cb_file_reference;
    gpointer cb_file_reference_data;
    set_orientation_t cb_set_orientation;
    gpointer cb_set_orientation_data;

    // Bounding box of data
    double global_mark_max_x;
    double global_mark_max_y;
    double global_mark_min_x;
    double global_mark_min_y;

    double quiver_scale;
};

#endif
